@@ -105,10 +105,13 @@ class ClusterOps(object):
         # filter out instances that are known to be on this host.
         nova_instances = [instance for instance in nova_instances if
                           self._this_node.upper() != instance.host.upper()]
+        instance_names = [instance.name for instance in nova_instances]
 
+        LOG.warning("Handling failovers that occurred while Nova was not "
+                    "running: %s", instance_names)
         for instance in nova_instances:
             utils.spawn_n(self._failover_migrate,
-                          instance.name, instance.host,
+                          instance.name,
                           self._this_node)
 
     @coordination.synchronized('failover-{instance_name}')
@@ -151,19 +154,18 @@ class ClusterOps(object):
         migrated_here = new_host.upper() == self._this_node.upper()
         migrated_from_here = old_host.upper() == self._this_node.upper()
 
+        if instance.task_state == task_states.MIGRATING:
+            LOG.debug('Instance %s is being migrated by Nova. This '
+                      'will not be treated as a failover.',
+                      instance_name)
+            return
+
         if not host_changed:
             LOG.warning("The source node is the same as the destination "
                         "node: %(host)s. The instance %(instance)s may have "
                         "bounced between hosts due to a failure.",
                         dict(host=old_host, instance=instance_name))
 
-        if instance.task_state == task_states.MIGRATING:
-            # In case of live migration triggered by the user, we get the
-            # event that the instance changed host but we do not want
-            # to treat it as a failover.
-            LOG.debug('Instance %s is live migrating.', instance_name)
-            return
-
         nw_info = self._network_api.get_instance_nw_info(self._context,
                                                          instance)
         if host_changed and migrated_from_here:
@@ -189,7 +191,10 @@ class ClusterOps(object):
                 LOG.exception("Could not update failed over instance '%s' "
                               "allocations.", instance)
 
+        if CONF.hyperv.recreate_ports_on_failover:
+            self._vmops.unplug_vifs(instance, nw_info)
         self._vmops.plug_vifs(instance, nw_info)
+
         self._serial_console_ops.start_console_handler(instance_name)
 
     def _wait_for_pending_instance(self, instance_name):
@@ -219,8 +224,10 @@ class ClusterOps(object):
             self._context, instance, migration)
         self._network_api.setup_networks_on_host(
             self._context, instance, self._this_node)
+        # TODO(lpetrut): provide the actual port provider mappings.
         self._network_api.migrate_instance_finish(
-            self._context, instance, migration)
+            self._context, instance, migration,
+            provider_mappings=None)
         self._network_api.setup_networks_on_host(
             self._context, instance, self._this_node)
         self._network_api.setup_networks_on_host(
