@@ -118,19 +118,6 @@ class VMOps(object):
     def list_instances(self):
         return self._vmutils.list_instances()
 
-    def estimate_instance_overhead(self, instance_info):
-        # NOTE(claudiub): When an instance starts, Hyper-V creates a VM memory
-        # file on the local disk. The file size is the same as the VM's amount
-        # of memory. Since disk_gb must be an integer, and memory is MB, round
-        # up from X512 MB.
-        # This applies only when the host is configured to save the instances
-        # when turning off.
-        disk_overhead = ((instance_info['memory_mb'] + 512) // units.Ki
-                          if not CONF.hyperv.instance_automatic_shutdown
-                          else 0)
-        return {'memory_mb': 0,
-                'disk_gb': disk_overhead}
-
     def get_info(self, instance):
         """Get information about the VM."""
         LOG.debug("get_info called for instance", instance=instance)
@@ -300,7 +287,8 @@ class VMOps(object):
 
     @check_admin_permissions
     def spawn(self, context, instance, image_meta, injected_files,
-              admin_password, network_info, block_device_info=None):
+              admin_password, network_info, block_device_info=None,
+              power_on=True):
         """Create a new VM and start it."""
         LOG.info("Spawning new instance", instance=instance)
 
@@ -344,9 +332,10 @@ class VMOps(object):
             # vifs are already plugged in at this point. We waited on the vif
             # plug event previously when we created the instance. Skip the
             # plug vifs during power on in this case
-            self.power_on(instance,
-                          network_info=network_info,
-                          should_plug_vifs=False)
+            if power_on:
+                self.power_on(instance,
+                              network_info=network_info,
+                              should_plug_vifs=False)
         except Exception:
             with excutils.save_and_reraise_exception():
                 self.destroy(instance, network_info, block_device_info)
